@@ -262,18 +262,7 @@
             window.app = this;
 
 
-            window.menus.forEach(item => {
-                item.icon = getIcon(item.name, item.icon);
-
-                if (item.models) {
-                    item.models.forEach(mItem => {
-                        mItem.icon = getIcon(mItem.name, mItem.icon);
-                        self.menuData.push(mItem)
-                    });
-                } else {
-                    self.menuData.push(item)
-                }
-            });
+            menus = this.handlerMenus(menus);
 
             this.menus = window.menus
 
@@ -289,13 +278,6 @@
                     themeEvents.push(handler);
                 } else if (name == 'font') {
                     fontEvents.push(handler);
-                }else if(name=='title'){
-                    console.log(handler)
-                    app.tabs.forEach(item=>{
-                        if(item.eid==app.tabModel){
-                            item.name = handler;
-                        }
-                    })
                 }
             }
             var temp_tabs = sessionStorage['tabs'];
@@ -318,6 +300,25 @@
             });
         },
         methods: {
+            handlerMenus(menus) {
+                let self = this;
+                menus.forEach(item => {
+                    item.icon = getIcon(item.name, item.icon);
+
+                    if (item.models) {
+                        item.models.forEach(mItem => {
+                            mItem.icon = getIcon(mItem.name, mItem.icon);
+                            self.menuData.push(mItem)
+                            if(mItem.models){
+                                self.handlerMenus(mItem.models);
+                            }
+                        });
+                    } else {
+                        self.menuData.push(item)
+                    }
+                });
+                return menus;
+            },
             syncTabs: function () {
                 if (window.sessionStorage) {
                     sessionStorage['tabs'] = JSON.stringify(this.tabs);
@@ -391,11 +392,11 @@
                 this.popup.show = true;
                 this.$nextTick(function () {
                     let el = this.$refs.popupmenu;
-                    el.style.width='150px';
+                    el.style.width = '150px';
                     let x = e.clientX;
 
-                    let w= document.body.offsetWidth
-                    if(x+150>w){
+                    let w = document.body.offsetWidth
+                    if (x + 150 > w) {
                         x = w - 160;
                     }
 
@@ -592,7 +593,7 @@
             report: function (url) {
                 if (!url) {
                     if (document.querySelector('html').lang) {
-                        url = 'https://simpleui.88cto.com';
+                        url = 'https://simpleui.72wo.com';
                     } else {
                         url = 'https://github.com/newpanjing/simpleui/issues';
                     }
